@@ -98,6 +98,12 @@ renv_lockfile_fini <- function(lockfile, project) {
 
 renv_lockfile_fini_bioconductor <- function(lockfile, project) {
 
+  # check for explicit version in settings
+  version <- settings$bioconductor.version(project = project)
+  if (length(version))
+    return(list(Version = version))
+
+  # otherwise, check for a package which required Bioconductor
   records <- renv_records(lockfile)
   if (empty(records))
     return(NULL)
@@ -110,6 +116,9 @@ renv_lockfile_fini_bioconductor <- function(lockfile, project) {
   if ("Bioconductor" %in% sources)
     return(list(Version = renv_bioconductor_version(project = project)))
 
+  # nothing found; return NULL
+  NULL
+
 }
 
 renv_lockfile_path <- function(project) {
@@ -146,7 +155,7 @@ renv_lockfile_sort <- function(lockfile) {
   renv_records(lockfile) <- sorted
 
   # sort top-level fields
-  fields <- unique(c("R", "Python", "Packages"), names(lockfile))
+  fields <- unique(c("R", "Bioconductor", "Python", "Packages", names(lockfile)))
   lockfile <- lockfile[intersect(fields, names(lockfile))]
 
   # return post-sort
@@ -160,11 +169,11 @@ renv_lockfile_create <- function(project, libpaths, type, packages) {
 
   renv_records(lockfile) <-
 
-    renv_snapshot_r_packages(libpaths = libpaths,
-                             project  = project) %>%
+    renv_snapshot_libpaths(libpaths = libpaths,
+                           project  = project) %>%
 
-    renv_snapshot_filter(project = project,
-                         type = type,
+    renv_snapshot_filter(project  = project,
+                         type     = type,
                          packages = packages) %>%
 
     renv_snapshot_fixup()
