@@ -61,7 +61,7 @@ migrate <- function(
   renv_scope_error_handler()
 
   project <- renv_project_resolve(project)
-  renv_scope_lock(project = project)
+  renv_project_lock(project = project)
 
   # for jetpack
   if (renv_package_checking())
