@@ -26,7 +26,7 @@
 modify <- function(project = NULL, changes = NULL) {
   renv_scope_error_handler()
   project <- renv_project_resolve(project)
-  renv_scope_lock(project = project)
+  renv_project_lock(project = project)
   renv_modify_impl(project, changes)
   invisible(project)
 }
