@@ -21,11 +21,10 @@ renv_mran_database_encode_impl <- function(entry) {
 
   splat <- strsplit(keys, " ", fixed = TRUE)
 
-  encoded <- data.frame(
+  encoded <- data_frame(
     Package          = map_chr(splat, `[[`, 1L),
     Version          = map_chr(splat, `[[`, 2L),
-    Date             = as.integer(vals),
-    stringsAsFactors = FALSE
+    Date             = as.integer(vals)
   )
 
   encoded <- encoded[order(encoded$Package, encoded$Version), ]
@@ -52,7 +51,10 @@ renv_mran_database_decode_impl <- function(entry) {
   vals <- as.list(entry$Date)
   names(vals) <- keys
 
-  list2env(vals, parent = emptyenv())
+  envir <- list2env(vals, parent = emptyenv())
+  attr(envir, "keys") <- keys
+
+  envir
 
 }
 
@@ -70,8 +72,13 @@ renv_mran_database_save <- function(database, path = NULL) {
 }
 
 renv_mran_database_load <- function(path = NULL) {
-  path <- path %||% renv_mran_database_path()
-  filebacked("mran", path, renv_mran_database_load_impl)
+
+  filebacked(
+    scope    = "renv_mran_database_load",
+    path     = path %||% renv_mran_database_path(),
+    callback = renv_mran_database_load_impl
+  )
+
 }
 
 renv_mran_database_load_impl <- function(path) {
@@ -98,8 +105,9 @@ renv_mran_database_dates <- function(version, all = TRUE) {
     "3.6" = "2019-04-26",
     "4.0" = "2020-04-24",
     "4.1" = "2021-05-18",
-    "4.2" = "2022-05-18",  # projected
-    "4.3" = "2023-05-18",  # projected
+    "4.2" = "2022-04-22",
+    "4.3" = "2023-05-18",  # a guess
+    "4.4" = "2024-05-18",  # a guess
     NULL
   )
 
@@ -108,11 +116,13 @@ renv_mran_database_dates <- function(version, all = TRUE) {
   if (is.na(index))
     stopf("no known release date for R %s", version)
 
-  start <- as.Date(releases[[index + 0]])
+  start <- as.Date(releases[[index]])
   if (!all)
     return(start)
 
   # form end date (ensure not in future)
+  # we look 2 releases in the future as R builds binaries for
+  # the previous releases of R as well
   end <- min(
     as.Date(releases[[index + 2L]]),
     as.Date(Sys.time(), tz = "UTC")
@@ -167,7 +177,7 @@ renv_mran_database_update_impl <- function(date, url, entry) {
 
   # retrieve available packages
   errors <- new.env(parent = emptyenv())
-  db <- renv_available_packages_query(url, errors)
+  db <- renv_available_packages_query_impl(url, errors)
   if (is.null(db)) {
     vwritef("ERROR")
     return(FALSE)
@@ -210,6 +220,13 @@ renv_mran_database_refresh <- function(explicit = TRUE) {
 }
 
 renv_mran_database_refresh_required <- function() {
+  dynamic(
+    key   = list(),
+    value = renv_mran_database_refresh_required_impl()
+  )
+}
+
+renv_mran_database_refresh_required_impl <- function() {
 
   # if the cache doesn't exist, we must refresh
   path <- renv_mran_database_path()
