@@ -4,7 +4,7 @@ stack <- function(mode = "list") {
   .data <- list()
   storage.mode(.data) <- mode
 
-  object <- list(
+  list(
 
     push = function(...) {
       dots <- list(...)
@@ -52,6 +52,4 @@ stack <- function(mode = "list") {
 
   )
 
-  object
-
 }
