@@ -37,9 +37,10 @@ status <- function(project = NULL,
   renv_dots_check(...)
 
   renv_snapshot_auto_suppress_next()
+  renv_scope_options(renv.prompt.enabled = FALSE)
 
   project <- renv_project_resolve(project)
-  renv_scope_lock(project = project)
+  renv_project_lock(project = project)
 
   libpaths <- renv_libpaths_resolve(library)
   lockpath <- lockfile %||% renv_lockfile_path(project)
@@ -55,6 +56,7 @@ renv_status_impl <- function(project, libpaths, lockpath, sources, cache) {
     return(list(library = list(), lockfile = list(), synchronized = FALSE))
   }
 
+  # collect library, lockfile state
   libstate <- renv_status_check_missing_library(project, libpaths)
   lockfile <- renv_status_check_missing_lockfile(project, lockpath)
 
@@ -134,7 +136,7 @@ renv_status_check_used_packages <- function(project, lockfile, libstate) {
   # only done when using implicit snapshots in a project
   type <- settings$snapshot.type(project = project)
   if (!type %in% c("implicit", "packrat"))
-    return(FALSE)
+    return(TRUE)
 
   deps <- dependencies(project, progress = FALSE)
   used <- sort(unique(deps$Package))
@@ -143,7 +145,8 @@ renv_status_check_used_packages <- function(project, lockfile, libstate) {
     renv_packages_base(),
     renv_project_ignored_packages(project),
     names(renv_records(lockfile)),
-    names(renv_records(libstate))
+    names(renv_records(libstate)),
+    "renv"
   )
 
   missing <- setdiff(used, ignored)
@@ -183,6 +186,20 @@ renv_status_check_synchronized <- function(project,
   if (empty(actions))
     return(TRUE)
 
+  # short-circuit for case where no packages (except renv) are installed
+  if (all(actions[setdiff(names(actions), "renv")] == "remove")) {
+
+    records <- renv_records_select(lockfile, actions, "remove")
+    renv_pretty_print_records(
+      records,
+      "The following package(s) are recorded in the lockfile, but not installed:",
+      "Use `renv::restore()` to install these packages."
+    )
+
+    return(FALSE)
+
+  }
+
   if ("install" %in% actions) {
 
     records <- renv_records_select(libstate, actions, "install")
@@ -207,6 +224,7 @@ renv_status_check_synchronized <- function(project,
     # installed in the project library anymore
     records <- renv_records_select(lockfile, actions, "remove")
 
+    unused <- NULL
     if (settings$snapshot.type() %in% c("implicit", "packrat")) {
 
       deps <- dependencies(project, progress = FALSE)
@@ -217,19 +235,7 @@ renv_status_check_synchronized <- function(project,
       )
 
       used <- intersect(names(records), names(pkgpaths))
-      unused <- setdiff(names(records), used)
-
-      if (renv_tests_running()) {
-        condition <- "renv.status.recorded_but_no_longer_used"
-        renv_condition_signal(condition, records[unused])
-      }
-
-      renv_pretty_print_records(
-        records[unused],
-        "The following package(s) do not appear to be used in this project:",
-        "Use `renv::snapshot()` to remove them from the lockfile."
-      )
-
+      unused <- keep(records, setdiff(names(records), used))
       records <- records[used]
 
     }
@@ -275,6 +281,29 @@ renv_status_check_synchronized <- function(project,
 
     }
 
+    if (length(unused)) {
+
+      if (renv_tests_running()) {
+        condition <- "renv.status.recorded_but_no_longer_used"
+        renv_condition_signal(condition, unused)
+      }
+
+      preamble <- "The following package(s) do not appear to be used in this project:"
+      postamble <- if (length(records)) c(
+        "Consider using `renv::restore()` to synchronize the library with the lockfile.",
+        "After, you may want to use `renv::snapshot()` to remove unused packages (if any)."
+      ) else c(
+        "Use `renv::snapshot()` to remove them from the lockfile."
+      )
+
+      renv_pretty_print_records(
+        records   = unused,
+        preamble  = preamble,
+        postamble = postamble
+      )
+
+    }
+
   }
 
   rest <- c("upgrade", "downgrade", "crossgrade")
