@@ -2,6 +2,9 @@
 # simulate running in R CMD check
 Sys.setenv("_R_CHECK_PACKAGE_NAME_" = "renv")
 
+# disable locking in this scope
+Sys.setenv(RENV_CONFIG_LOCKING_ENABLED = FALSE)
+
 context <- function(desc) {
   renv_tests_init()
   testthat::context(desc)
@@ -18,6 +21,7 @@ test_that <- function(desc, code) {
 
   oldlibpaths <- .libPaths()
   oldrepos <- getOption("repos")
+  oldconns <- getAllConnections()
 
   repopath <- getOption("renv.tests.repopath")
   oldrepofiles <- list.files(
@@ -71,6 +75,12 @@ test_that <- function(desc, code) {
     stopf("test %s has corrupted packages in repository", shQuote(desc))
   }
 
+  newconns <- getAllConnections()
+  if (!identical(oldconns, newconns)) {
+    print(newconns)
+    stopf("test %s has leaked connections", shQuote(desc))
+  }
+
   newuserfiles <- list.files(
     path       = olduserdir,
     all.files  = TRUE,
