@@ -3,5 +3,5 @@ box::use(
     A,
     b = B,
     C[...],
-    D[c, d],
+    D[c, d]
 )
